import builtins  # noqa: F401
from files_sdk.api import Api  # noqa: F401
from files_sdk.list_obj import ListObj
from files_sdk.error import (  # noqa: F401
    InvalidParameterError,
    MissingParameterError,
    NotImplementedError,
)


class FtpActionLog:
    default_attributes = {
        "timestamp": None,  # date-time - Start Time of Action
        "remote_ip": None,  # string - IP Address of FTP Client
        "server_ip": None,  # string - IP Address of FTP Server
        "username": None,  # string - Username
        "session_uid": None,  # string - Unique ID of the Session
        "seq_id": None,  # int64 - FTP Sequence ID
        "action_type": None,  # string - Action Type
        "path": None,  # string - Path as sent by the Client (may not match Files.com path due to user root folders for FTP) This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.
        "true_path": None,  # string - Path on Files.com
        "name": None,  # string - Name of File
        "cmd": None,  # string - FTP Command Name
        "param": None,  # string - FTP Command Param
        "responseCode": None,  # string - FTP Response Code
        "responseMessage": None,  # string - FTP Response Message
        "entries_returned": None,  # int64 - Number of entries returned when listing files and folders
        "success": None,  # string - Whether FTP Action was successful.
        "duration_ms": None,  # int64 - Duration (in milliseconds)
    }

    def __init__(self, attributes=None, options=None):
        if not isinstance(attributes, dict):
            attributes = {}
        if not isinstance(options, dict):
            options = {}
        self.set_attributes(attributes)
        self.options = options

    def set_attributes(self, attributes):
        for (
            attribute,
            default_value,
        ) in FtpActionLog.default_attributes.items():
            setattr(self, attribute, attributes.get(attribute, default_value))

    def get_attributes(self):
        return {
            k: getattr(self, k, None)
            for k in FtpActionLog.default_attributes
            if getattr(self, k, None) is not None
        }


# Parameters:
#   cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
#   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `start_date`, `end_date`, `path`, `true_path`, `remote_ip`, `session_uuid`, `success`, `type` or `username`. Valid field combinations are `[ start_date ]`, `[ end_date ]`, `[ path ]`, `[ true_path ]`, `[ remote_ip ]`, `[ session_uuid ]`, `[ success ]`, `[ type ]`, `[ username ]`, `[ start_date, end_date ]`, `[ start_date, path ]`, `[ start_date, true_path ]`, `[ start_date, remote_ip ]`, `[ start_date, session_uuid ]`, `[ start_date, success ]`, `[ start_date, type ]`, `[ start_date, username ]`, `[ end_date, path ]`, `[ end_date, true_path ]`, `[ end_date, remote_ip ]`, `[ end_date, session_uuid ]`, `[ end_date, success ]`, `[ end_date, type ]`, `[ end_date, username ]`, `[ path, true_path ]`, `[ path, remote_ip ]`, `[ path, session_uuid ]`, `[ path, success ]`, `[ path, type ]`, `[ path, username ]`, `[ true_path, remote_ip ]`, `[ true_path, session_uuid ]`, `[ true_path, success ]`, `[ true_path, type ]`, `[ true_path, username ]`, `[ remote_ip, session_uuid ]`, `[ remote_ip, success ]`, `[ remote_ip, type ]`, `[ remote_ip, username ]`, `[ session_uuid, success ]`, `[ session_uuid, type ]`, `[ session_uuid, username ]`, `[ success, type ]`, `[ success, username ]`, `[ type, username ]`, `[ start_date, end_date, path ]`, `[ start_date, end_date, true_path ]`, `[ start_date, end_date, remote_ip ]`, `[ start_date, end_date, session_uuid ]`, `[ start_date, end_date, success ]`, `[ start_date, end_date, type ]`, `[ start_date, end_date, username ]`, `[ start_date, path, true_path ]`, `[ start_date, path, remote_ip ]`, `[ start_date, path, session_uuid ]`, `[ start_date, path, success ]`, `[ start_date, path, type ]`, `[ start_date, path, username ]`, `[ start_date, true_path, remote_ip ]`, `[ start_date, true_path, session_uuid ]`, `[ start_date, true_path, success ]`, `[ start_date, true_path, type ]`, `[ start_date, true_path, username ]`, `[ start_date, remote_ip, session_uuid ]`, `[ start_date, remote_ip, success ]`, `[ start_date, remote_ip, type ]`, `[ start_date, remote_ip, username ]`, `[ start_date, session_uuid, success ]`, `[ start_date, session_uuid, type ]`, `[ start_date, session_uuid, username ]`, `[ start_date, success, type ]`, `[ start_date, success, username ]`, `[ start_date, type, username ]`, `[ end_date, path, true_path ]`, `[ end_date, path, remote_ip ]`, `[ end_date, path, session_uuid ]`, `[ end_date, path, success ]`, `[ end_date, path, type ]`, `[ end_date, path, username ]`, `[ end_date, true_path, remote_ip ]`, `[ end_date, true_path, session_uuid ]`, `[ end_date, true_path, success ]`, `[ end_date, true_path, type ]`, `[ end_date, true_path, username ]`, `[ end_date, remote_ip, session_uuid ]`, `[ end_date, remote_ip, success ]`, `[ end_date, remote_ip, type ]`, `[ end_date, remote_ip, username ]`, `[ end_date, session_uuid, success ]`, `[ end_date, session_uuid, type ]`, `[ end_date, session_uuid, username ]`, `[ end_date, success, type ]`, `[ end_date, success, username ]`, `[ end_date, type, username ]`, `[ path, true_path, remote_ip ]`, `[ path, true_path, session_uuid ]`, `[ path, true_path, success ]`, `[ path, true_path, type ]`, `[ path, true_path, username ]`, `[ path, remote_ip, session_uuid ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, type ]`, `[ path, remote_ip, username ]`, `[ path, session_uuid, success ]`, `[ path, session_uuid, type ]`, `[ path, session_uuid, username ]`, `[ path, success, type ]`, `[ path, success, username ]`, `[ path, type, username ]`, `[ true_path, remote_ip, session_uuid ]`, `[ true_path, remote_ip, success ]`, `[ true_path, remote_ip, type ]`, `[ true_path, remote_ip, username ]`, `[ true_path, session_uuid, success ]`, `[ true_path, session_uuid, type ]`, `[ true_path, session_uuid, username ]`, `[ true_path, success, type ]`, `[ true_path, success, username ]`, `[ true_path, type, username ]`, `[ remote_ip, session_uuid, success ]`, `[ remote_ip, session_uuid, type ]`, `[ remote_ip, session_uuid, username ]`, `[ remote_ip, success, type ]`, `[ remote_ip, success, username ]`, `[ remote_ip, type, username ]`, `[ session_uuid, success, type ]`, `[ session_uuid, success, username ]`, `[ session_uuid, type, username ]`, `[ success, type, username ]`, `[ start_date, end_date, path, true_path ]`, `[ start_date, end_date, path, remote_ip ]`, `[ start_date, end_date, path, session_uuid ]`, `[ start_date, end_date, path, success ]`, `[ start_date, end_date, path, type ]`, `[ start_date, end_date, path, username ]`, `[ start_date, end_date, true_path, remote_ip ]`, `[ start_date, end_date, true_path, session_uuid ]`, `[ start_date, end_date, true_path, success ]`, `[ start_date, end_date, true_path, type ]`, `[ start_date, end_date, true_path, username ]`, `[ start_date, end_date, remote_ip, session_uuid ]`, `[ start_date, end_date, remote_ip, success ]`, `[ start_date, end_date, remote_ip, type ]`, `[ start_date, end_date, remote_ip, username ]`, `[ start_date, end_date, session_uuid, success ]`, `[ start_date, end_date, session_uuid, type ]`, `[ start_date, end_date, session_uuid, username ]`, `[ start_date, end_date, success, type ]`, `[ start_date, end_date, success, username ]`, `[ start_date, end_date, type, username ]`, `[ start_date, path, true_path, remote_ip ]`, `[ start_date, path, true_path, session_uuid ]`, `[ start_date, path, true_path, success ]`, `[ start_date, path, true_path, type ]`, `[ start_date, path, true_path, username ]`, `[ start_date, path, remote_ip, session_uuid ]`, `[ start_date, path, remote_ip, success ]`, `[ start_date, path, remote_ip, type ]`, `[ start_date, path, remote_ip, username ]`, `[ start_date, path, session_uuid, success ]`, `[ start_date, path, session_uuid, type ]`, `[ start_date, path, session_uuid, username ]`, `[ start_date, path, success, type ]`, `[ start_date, path, success, username ]`, `[ start_date, path, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid ]`, `[ start_date, true_path, remote_ip, success ]`, `[ start_date, true_path, remote_ip, type ]`, `[ start_date, true_path, remote_ip, username ]`, `[ start_date, true_path, session_uuid, success ]`, `[ start_date, true_path, session_uuid, type ]`, `[ start_date, true_path, session_uuid, username ]`, `[ start_date, true_path, success, type ]`, `[ start_date, true_path, success, username ]`, `[ start_date, true_path, type, username ]`, `[ start_date, remote_ip, session_uuid, success ]`, `[ start_date, remote_ip, session_uuid, type ]`, `[ start_date, remote_ip, session_uuid, username ]`, `[ start_date, remote_ip, success, type ]`, `[ start_date, remote_ip, success, username ]`, `[ start_date, remote_ip, type, username ]`, `[ start_date, session_uuid, success, type ]`, `[ start_date, session_uuid, success, username ]`, `[ start_date, session_uuid, type, username ]`, `[ start_date, success, type, username ]`, `[ end_date, path, true_path, remote_ip ]`, `[ end_date, path, true_path, session_uuid ]`, `[ end_date, path, true_path, success ]`, `[ end_date, path, true_path, type ]`, `[ end_date, path, true_path, username ]`, `[ end_date, path, remote_ip, session_uuid ]`, `[ end_date, path, remote_ip, success ]`, `[ end_date, path, remote_ip, type ]`, `[ end_date, path, remote_ip, username ]`, `[ end_date, path, session_uuid, success ]`, `[ end_date, path, session_uuid, type ]`, `[ end_date, path, session_uuid, username ]`, `[ end_date, path, success, type ]`, `[ end_date, path, success, username ]`, `[ end_date, path, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid ]`, `[ end_date, true_path, remote_ip, success ]`, `[ end_date, true_path, remote_ip, type ]`, `[ end_date, true_path, remote_ip, username ]`, `[ end_date, true_path, session_uuid, success ]`, `[ end_date, true_path, session_uuid, type ]`, `[ end_date, true_path, session_uuid, username ]`, `[ end_date, true_path, success, type ]`, `[ end_date, true_path, success, username ]`, `[ end_date, true_path, type, username ]`, `[ end_date, remote_ip, session_uuid, success ]`, `[ end_date, remote_ip, session_uuid, type ]`, `[ end_date, remote_ip, session_uuid, username ]`, `[ end_date, remote_ip, success, type ]`, `[ end_date, remote_ip, success, username ]`, `[ end_date, remote_ip, type, username ]`, `[ end_date, session_uuid, success, type ]`, `[ end_date, session_uuid, success, username ]`, `[ end_date, session_uuid, type, username ]`, `[ end_date, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid ]`, `[ path, true_path, remote_ip, success ]`, `[ path, true_path, remote_ip, type ]`, `[ path, true_path, remote_ip, username ]`, `[ path, true_path, session_uuid, success ]`, `[ path, true_path, session_uuid, type ]`, `[ path, true_path, session_uuid, username ]`, `[ path, true_path, success, type ]`, `[ path, true_path, success, username ]`, `[ path, true_path, type, username ]`, `[ path, remote_ip, session_uuid, success ]`, `[ path, remote_ip, session_uuid, type ]`, `[ path, remote_ip, session_uuid, username ]`, `[ path, remote_ip, success, type ]`, `[ path, remote_ip, success, username ]`, `[ path, remote_ip, type, username ]`, `[ path, session_uuid, success, type ]`, `[ path, session_uuid, success, username ]`, `[ path, session_uuid, type, username ]`, `[ path, success, type, username ]`, `[ true_path, remote_ip, session_uuid, success ]`, `[ true_path, remote_ip, session_uuid, type ]`, `[ true_path, remote_ip, session_uuid, username ]`, `[ true_path, remote_ip, success, type ]`, `[ true_path, remote_ip, success, username ]`, `[ true_path, remote_ip, type, username ]`, `[ true_path, session_uuid, success, type ]`, `[ true_path, session_uuid, success, username ]`, `[ true_path, session_uuid, type, username ]`, `[ true_path, success, type, username ]`, `[ remote_ip, session_uuid, success, type ]`, `[ remote_ip, session_uuid, success, username ]`, `[ remote_ip, session_uuid, type, username ]`, `[ remote_ip, success, type, username ]`, `[ session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip ]`, `[ start_date, end_date, path, true_path, session_uuid ]`, `[ start_date, end_date, path, true_path, success ]`, `[ start_date, end_date, path, true_path, type ]`, `[ start_date, end_date, path, true_path, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid ]`, `[ start_date, end_date, path, remote_ip, success ]`, `[ start_date, end_date, path, remote_ip, type ]`, `[ start_date, end_date, path, remote_ip, username ]`, `[ start_date, end_date, path, session_uuid, success ]`, `[ start_date, end_date, path, session_uuid, type ]`, `[ start_date, end_date, path, session_uuid, username ]`, `[ start_date, end_date, path, success, type ]`, `[ start_date, end_date, path, success, username ]`, `[ start_date, end_date, path, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid ]`, `[ start_date, end_date, true_path, remote_ip, success ]`, `[ start_date, end_date, true_path, remote_ip, type ]`, `[ start_date, end_date, true_path, remote_ip, username ]`, `[ start_date, end_date, true_path, session_uuid, success ]`, `[ start_date, end_date, true_path, session_uuid, type ]`, `[ start_date, end_date, true_path, session_uuid, username ]`, `[ start_date, end_date, true_path, success, type ]`, `[ start_date, end_date, true_path, success, username ]`, `[ start_date, end_date, true_path, type, username ]`, `[ start_date, end_date, remote_ip, session_uuid, success ]`, `[ start_date, end_date, remote_ip, session_uuid, type ]`, `[ start_date, end_date, remote_ip, session_uuid, username ]`, `[ start_date, end_date, remote_ip, success, type ]`, `[ start_date, end_date, remote_ip, success, username ]`, `[ start_date, end_date, remote_ip, type, username ]`, `[ start_date, end_date, session_uuid, success, type ]`, `[ start_date, end_date, session_uuid, success, username ]`, `[ start_date, end_date, session_uuid, type, username ]`, `[ start_date, end_date, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid ]`, `[ start_date, path, true_path, remote_ip, success ]`, `[ start_date, path, true_path, remote_ip, type ]`, `[ start_date, path, true_path, remote_ip, username ]`, `[ start_date, path, true_path, session_uuid, success ]`, `[ start_date, path, true_path, session_uuid, type ]`, `[ start_date, path, true_path, session_uuid, username ]`, `[ start_date, path, true_path, success, type ]`, `[ start_date, path, true_path, success, username ]`, `[ start_date, path, true_path, type, username ]`, `[ start_date, path, remote_ip, session_uuid, success ]`, `[ start_date, path, remote_ip, session_uuid, type ]`, `[ start_date, path, remote_ip, session_uuid, username ]`, `[ start_date, path, remote_ip, success, type ]`, `[ start_date, path, remote_ip, success, username ]`, `[ start_date, path, remote_ip, type, username ]`, `[ start_date, path, session_uuid, success, type ]`, `[ start_date, path, session_uuid, success, username ]`, `[ start_date, path, session_uuid, type, username ]`, `[ start_date, path, success, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid, success ]`, `[ start_date, true_path, remote_ip, session_uuid, type ]`, `[ start_date, true_path, remote_ip, session_uuid, username ]`, `[ start_date, true_path, remote_ip, success, type ]`, `[ start_date, true_path, remote_ip, success, username ]`, `[ start_date, true_path, remote_ip, type, username ]`, `[ start_date, true_path, session_uuid, success, type ]`, `[ start_date, true_path, session_uuid, success, username ]`, `[ start_date, true_path, session_uuid, type, username ]`, `[ start_date, true_path, success, type, username ]`, `[ start_date, remote_ip, session_uuid, success, type ]`, `[ start_date, remote_ip, session_uuid, success, username ]`, `[ start_date, remote_ip, session_uuid, type, username ]`, `[ start_date, remote_ip, success, type, username ]`, `[ start_date, session_uuid, success, type, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid ]`, `[ end_date, path, true_path, remote_ip, success ]`, `[ end_date, path, true_path, remote_ip, type ]`, `[ end_date, path, true_path, remote_ip, username ]`, `[ end_date, path, true_path, session_uuid, success ]`, `[ end_date, path, true_path, session_uuid, type ]`, `[ end_date, path, true_path, session_uuid, username ]`, `[ end_date, path, true_path, success, type ]`, `[ end_date, path, true_path, success, username ]`, `[ end_date, path, true_path, type, username ]`, `[ end_date, path, remote_ip, session_uuid, success ]`, `[ end_date, path, remote_ip, session_uuid, type ]`, `[ end_date, path, remote_ip, session_uuid, username ]`, `[ end_date, path, remote_ip, success, type ]`, `[ end_date, path, remote_ip, success, username ]`, `[ end_date, path, remote_ip, type, username ]`, `[ end_date, path, session_uuid, success, type ]`, `[ end_date, path, session_uuid, success, username ]`, `[ end_date, path, session_uuid, type, username ]`, `[ end_date, path, success, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid, success ]`, `[ end_date, true_path, remote_ip, session_uuid, type ]`, `[ end_date, true_path, remote_ip, session_uuid, username ]`, `[ end_date, true_path, remote_ip, success, type ]`, `[ end_date, true_path, remote_ip, success, username ]`, `[ end_date, true_path, remote_ip, type, username ]`, `[ end_date, true_path, session_uuid, success, type ]`, `[ end_date, true_path, session_uuid, success, username ]`, `[ end_date, true_path, session_uuid, type, username ]`, `[ end_date, true_path, success, type, username ]`, `[ end_date, remote_ip, session_uuid, success, type ]`, `[ end_date, remote_ip, session_uuid, success, username ]`, `[ end_date, remote_ip, session_uuid, type, username ]`, `[ end_date, remote_ip, success, type, username ]`, `[ end_date, session_uuid, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid, success ]`, `[ path, true_path, remote_ip, session_uuid, type ]`, `[ path, true_path, remote_ip, session_uuid, username ]`, `[ path, true_path, remote_ip, success, type ]`, `[ path, true_path, remote_ip, success, username ]`, `[ path, true_path, remote_ip, type, username ]`, `[ path, true_path, session_uuid, success, type ]`, `[ path, true_path, session_uuid, success, username ]`, `[ path, true_path, session_uuid, type, username ]`, `[ path, true_path, success, type, username ]`, `[ path, remote_ip, session_uuid, success, type ]`, `[ path, remote_ip, session_uuid, success, username ]`, `[ path, remote_ip, session_uuid, type, username ]`, `[ path, remote_ip, success, type, username ]`, `[ path, session_uuid, success, type, username ]`, `[ true_path, remote_ip, session_uuid, success, type ]`, `[ true_path, remote_ip, session_uuid, success, username ]`, `[ true_path, remote_ip, session_uuid, type, username ]`, `[ true_path, remote_ip, success, type, username ]`, `[ true_path, session_uuid, success, type, username ]`, `[ remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid ]`, `[ start_date, end_date, path, true_path, remote_ip, success ]`, `[ start_date, end_date, path, true_path, remote_ip, type ]`, `[ start_date, end_date, path, true_path, remote_ip, username ]`, `[ start_date, end_date, path, true_path, session_uuid, success ]`, `[ start_date, end_date, path, true_path, session_uuid, type ]`, `[ start_date, end_date, path, true_path, session_uuid, username ]`, `[ start_date, end_date, path, true_path, success, type ]`, `[ start_date, end_date, path, true_path, success, username ]`, `[ start_date, end_date, path, true_path, type, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success ]`, `[ start_date, end_date, path, remote_ip, session_uuid, type ]`, `[ start_date, end_date, path, remote_ip, session_uuid, username ]`, `[ start_date, end_date, path, remote_ip, success, type ]`, `[ start_date, end_date, path, remote_ip, success, username ]`, `[ start_date, end_date, path, remote_ip, type, username ]`, `[ start_date, end_date, path, session_uuid, success, type ]`, `[ start_date, end_date, path, session_uuid, success, username ]`, `[ start_date, end_date, path, session_uuid, type, username ]`, `[ start_date, end_date, path, success, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, type ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, username ]`, `[ start_date, end_date, true_path, remote_ip, success, type ]`, `[ start_date, end_date, true_path, remote_ip, success, username ]`, `[ start_date, end_date, true_path, remote_ip, type, username ]`, `[ start_date, end_date, true_path, session_uuid, success, type ]`, `[ start_date, end_date, true_path, session_uuid, success, username ]`, `[ start_date, end_date, true_path, session_uuid, type, username ]`, `[ start_date, end_date, true_path, success, type, username ]`, `[ start_date, end_date, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, remote_ip, success, type, username ]`, `[ start_date, end_date, session_uuid, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success ]`, `[ start_date, path, true_path, remote_ip, session_uuid, type ]`, `[ start_date, path, true_path, remote_ip, session_uuid, username ]`, `[ start_date, path, true_path, remote_ip, success, type ]`, `[ start_date, path, true_path, remote_ip, success, username ]`, `[ start_date, path, true_path, remote_ip, type, username ]`, `[ start_date, path, true_path, session_uuid, success, type ]`, `[ start_date, path, true_path, session_uuid, success, username ]`, `[ start_date, path, true_path, session_uuid, type, username ]`, `[ start_date, path, true_path, success, type, username ]`, `[ start_date, path, remote_ip, session_uuid, success, type ]`, `[ start_date, path, remote_ip, session_uuid, success, username ]`, `[ start_date, path, remote_ip, session_uuid, type, username ]`, `[ start_date, path, remote_ip, success, type, username ]`, `[ start_date, path, session_uuid, success, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, true_path, remote_ip, success, type, username ]`, `[ start_date, true_path, session_uuid, success, type, username ]`, `[ start_date, remote_ip, session_uuid, success, type, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid, success ]`, `[ end_date, path, true_path, remote_ip, session_uuid, type ]`, `[ end_date, path, true_path, remote_ip, session_uuid, username ]`, `[ end_date, path, true_path, remote_ip, success, type ]`, `[ end_date, path, true_path, remote_ip, success, username ]`, `[ end_date, path, true_path, remote_ip, type, username ]`, `[ end_date, path, true_path, session_uuid, success, type ]`, `[ end_date, path, true_path, session_uuid, success, username ]`, `[ end_date, path, true_path, session_uuid, type, username ]`, `[ end_date, path, true_path, success, type, username ]`, `[ end_date, path, remote_ip, session_uuid, success, type ]`, `[ end_date, path, remote_ip, session_uuid, success, username ]`, `[ end_date, path, remote_ip, session_uuid, type, username ]`, `[ end_date, path, remote_ip, success, type, username ]`, `[ end_date, path, session_uuid, success, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid, success, type ]`, `[ end_date, true_path, remote_ip, session_uuid, success, username ]`, `[ end_date, true_path, remote_ip, session_uuid, type, username ]`, `[ end_date, true_path, remote_ip, success, type, username ]`, `[ end_date, true_path, session_uuid, success, type, username ]`, `[ end_date, remote_ip, session_uuid, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid, success, type ]`, `[ path, true_path, remote_ip, session_uuid, success, username ]`, `[ path, true_path, remote_ip, session_uuid, type, username ]`, `[ path, true_path, remote_ip, success, type, username ]`, `[ path, true_path, session_uuid, success, type, username ]`, `[ path, remote_ip, session_uuid, success, type, username ]`, `[ true_path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, success ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, type ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, username ]`, `[ start_date, end_date, path, true_path, remote_ip, success, type ]`, `[ start_date, end_date, path, true_path, remote_ip, success, username ]`, `[ start_date, end_date, path, true_path, remote_ip, type, username ]`, `[ start_date, end_date, path, true_path, session_uuid, success, type ]`, `[ start_date, end_date, path, true_path, session_uuid, success, username ]`, `[ start_date, end_date, path, true_path, session_uuid, type, username ]`, `[ start_date, end_date, path, true_path, success, type, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, path, remote_ip, success, type, username ]`, `[ start_date, end_date, path, session_uuid, success, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, true_path, remote_ip, success, type, username ]`, `[ start_date, end_date, true_path, session_uuid, success, type, username ]`, `[ start_date, end_date, remote_ip, session_uuid, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, path, true_path, remote_ip, success, type, username ]`, `[ start_date, path, true_path, session_uuid, success, type, username ]`, `[ start_date, path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid, success, type, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid, success, type ]`, `[ end_date, path, true_path, remote_ip, session_uuid, success, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid, type, username ]`, `[ end_date, path, true_path, remote_ip, success, type, username ]`, `[ end_date, path, true_path, session_uuid, success, type, username ]`, `[ end_date, path, remote_ip, session_uuid, success, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, success, type, username ]`, `[ start_date, end_date, path, true_path, session_uuid, success, type, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success, type, username ]` or `[ end_date, path, true_path, remote_ip, session_uuid, success, type, username ]`.
#   filter_prefix - object - If set, return records where the specified field is prefixed by the supplied value. Valid fields are `path`, `true_path`, `success` or `username`. Valid field combinations are `[ start_date ]`, `[ end_date ]`, `[ path ]`, `[ true_path ]`, `[ remote_ip ]`, `[ session_uuid ]`, `[ success ]`, `[ type ]`, `[ username ]`, `[ start_date, end_date ]`, `[ start_date, path ]`, `[ start_date, true_path ]`, `[ start_date, remote_ip ]`, `[ start_date, session_uuid ]`, `[ start_date, success ]`, `[ start_date, type ]`, `[ start_date, username ]`, `[ end_date, path ]`, `[ end_date, true_path ]`, `[ end_date, remote_ip ]`, `[ end_date, session_uuid ]`, `[ end_date, success ]`, `[ end_date, type ]`, `[ end_date, username ]`, `[ path, true_path ]`, `[ path, remote_ip ]`, `[ path, session_uuid ]`, `[ path, success ]`, `[ path, type ]`, `[ path, username ]`, `[ true_path, remote_ip ]`, `[ true_path, session_uuid ]`, `[ true_path, success ]`, `[ true_path, type ]`, `[ true_path, username ]`, `[ remote_ip, session_uuid ]`, `[ remote_ip, success ]`, `[ remote_ip, type ]`, `[ remote_ip, username ]`, `[ session_uuid, success ]`, `[ session_uuid, type ]`, `[ session_uuid, username ]`, `[ success, type ]`, `[ success, username ]`, `[ type, username ]`, `[ start_date, end_date, path ]`, `[ start_date, end_date, true_path ]`, `[ start_date, end_date, remote_ip ]`, `[ start_date, end_date, session_uuid ]`, `[ start_date, end_date, success ]`, `[ start_date, end_date, type ]`, `[ start_date, end_date, username ]`, `[ start_date, path, true_path ]`, `[ start_date, path, remote_ip ]`, `[ start_date, path, session_uuid ]`, `[ start_date, path, success ]`, `[ start_date, path, type ]`, `[ start_date, path, username ]`, `[ start_date, true_path, remote_ip ]`, `[ start_date, true_path, session_uuid ]`, `[ start_date, true_path, success ]`, `[ start_date, true_path, type ]`, `[ start_date, true_path, username ]`, `[ start_date, remote_ip, session_uuid ]`, `[ start_date, remote_ip, success ]`, `[ start_date, remote_ip, type ]`, `[ start_date, remote_ip, username ]`, `[ start_date, session_uuid, success ]`, `[ start_date, session_uuid, type ]`, `[ start_date, session_uuid, username ]`, `[ start_date, success, type ]`, `[ start_date, success, username ]`, `[ start_date, type, username ]`, `[ end_date, path, true_path ]`, `[ end_date, path, remote_ip ]`, `[ end_date, path, session_uuid ]`, `[ end_date, path, success ]`, `[ end_date, path, type ]`, `[ end_date, path, username ]`, `[ end_date, true_path, remote_ip ]`, `[ end_date, true_path, session_uuid ]`, `[ end_date, true_path, success ]`, `[ end_date, true_path, type ]`, `[ end_date, true_path, username ]`, `[ end_date, remote_ip, session_uuid ]`, `[ end_date, remote_ip, success ]`, `[ end_date, remote_ip, type ]`, `[ end_date, remote_ip, username ]`, `[ end_date, session_uuid, success ]`, `[ end_date, session_uuid, type ]`, `[ end_date, session_uuid, username ]`, `[ end_date, success, type ]`, `[ end_date, success, username ]`, `[ end_date, type, username ]`, `[ path, true_path, remote_ip ]`, `[ path, true_path, session_uuid ]`, `[ path, true_path, success ]`, `[ path, true_path, type ]`, `[ path, true_path, username ]`, `[ path, remote_ip, session_uuid ]`, `[ path, remote_ip, success ]`, `[ path, remote_ip, type ]`, `[ path, remote_ip, username ]`, `[ path, session_uuid, success ]`, `[ path, session_uuid, type ]`, `[ path, session_uuid, username ]`, `[ path, success, type ]`, `[ path, success, username ]`, `[ path, type, username ]`, `[ true_path, remote_ip, session_uuid ]`, `[ true_path, remote_ip, success ]`, `[ true_path, remote_ip, type ]`, `[ true_path, remote_ip, username ]`, `[ true_path, session_uuid, success ]`, `[ true_path, session_uuid, type ]`, `[ true_path, session_uuid, username ]`, `[ true_path, success, type ]`, `[ true_path, success, username ]`, `[ true_path, type, username ]`, `[ remote_ip, session_uuid, success ]`, `[ remote_ip, session_uuid, type ]`, `[ remote_ip, session_uuid, username ]`, `[ remote_ip, success, type ]`, `[ remote_ip, success, username ]`, `[ remote_ip, type, username ]`, `[ session_uuid, success, type ]`, `[ session_uuid, success, username ]`, `[ session_uuid, type, username ]`, `[ success, type, username ]`, `[ start_date, end_date, path, true_path ]`, `[ start_date, end_date, path, remote_ip ]`, `[ start_date, end_date, path, session_uuid ]`, `[ start_date, end_date, path, success ]`, `[ start_date, end_date, path, type ]`, `[ start_date, end_date, path, username ]`, `[ start_date, end_date, true_path, remote_ip ]`, `[ start_date, end_date, true_path, session_uuid ]`, `[ start_date, end_date, true_path, success ]`, `[ start_date, end_date, true_path, type ]`, `[ start_date, end_date, true_path, username ]`, `[ start_date, end_date, remote_ip, session_uuid ]`, `[ start_date, end_date, remote_ip, success ]`, `[ start_date, end_date, remote_ip, type ]`, `[ start_date, end_date, remote_ip, username ]`, `[ start_date, end_date, session_uuid, success ]`, `[ start_date, end_date, session_uuid, type ]`, `[ start_date, end_date, session_uuid, username ]`, `[ start_date, end_date, success, type ]`, `[ start_date, end_date, success, username ]`, `[ start_date, end_date, type, username ]`, `[ start_date, path, true_path, remote_ip ]`, `[ start_date, path, true_path, session_uuid ]`, `[ start_date, path, true_path, success ]`, `[ start_date, path, true_path, type ]`, `[ start_date, path, true_path, username ]`, `[ start_date, path, remote_ip, session_uuid ]`, `[ start_date, path, remote_ip, success ]`, `[ start_date, path, remote_ip, type ]`, `[ start_date, path, remote_ip, username ]`, `[ start_date, path, session_uuid, success ]`, `[ start_date, path, session_uuid, type ]`, `[ start_date, path, session_uuid, username ]`, `[ start_date, path, success, type ]`, `[ start_date, path, success, username ]`, `[ start_date, path, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid ]`, `[ start_date, true_path, remote_ip, success ]`, `[ start_date, true_path, remote_ip, type ]`, `[ start_date, true_path, remote_ip, username ]`, `[ start_date, true_path, session_uuid, success ]`, `[ start_date, true_path, session_uuid, type ]`, `[ start_date, true_path, session_uuid, username ]`, `[ start_date, true_path, success, type ]`, `[ start_date, true_path, success, username ]`, `[ start_date, true_path, type, username ]`, `[ start_date, remote_ip, session_uuid, success ]`, `[ start_date, remote_ip, session_uuid, type ]`, `[ start_date, remote_ip, session_uuid, username ]`, `[ start_date, remote_ip, success, type ]`, `[ start_date, remote_ip, success, username ]`, `[ start_date, remote_ip, type, username ]`, `[ start_date, session_uuid, success, type ]`, `[ start_date, session_uuid, success, username ]`, `[ start_date, session_uuid, type, username ]`, `[ start_date, success, type, username ]`, `[ end_date, path, true_path, remote_ip ]`, `[ end_date, path, true_path, session_uuid ]`, `[ end_date, path, true_path, success ]`, `[ end_date, path, true_path, type ]`, `[ end_date, path, true_path, username ]`, `[ end_date, path, remote_ip, session_uuid ]`, `[ end_date, path, remote_ip, success ]`, `[ end_date, path, remote_ip, type ]`, `[ end_date, path, remote_ip, username ]`, `[ end_date, path, session_uuid, success ]`, `[ end_date, path, session_uuid, type ]`, `[ end_date, path, session_uuid, username ]`, `[ end_date, path, success, type ]`, `[ end_date, path, success, username ]`, `[ end_date, path, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid ]`, `[ end_date, true_path, remote_ip, success ]`, `[ end_date, true_path, remote_ip, type ]`, `[ end_date, true_path, remote_ip, username ]`, `[ end_date, true_path, session_uuid, success ]`, `[ end_date, true_path, session_uuid, type ]`, `[ end_date, true_path, session_uuid, username ]`, `[ end_date, true_path, success, type ]`, `[ end_date, true_path, success, username ]`, `[ end_date, true_path, type, username ]`, `[ end_date, remote_ip, session_uuid, success ]`, `[ end_date, remote_ip, session_uuid, type ]`, `[ end_date, remote_ip, session_uuid, username ]`, `[ end_date, remote_ip, success, type ]`, `[ end_date, remote_ip, success, username ]`, `[ end_date, remote_ip, type, username ]`, `[ end_date, session_uuid, success, type ]`, `[ end_date, session_uuid, success, username ]`, `[ end_date, session_uuid, type, username ]`, `[ end_date, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid ]`, `[ path, true_path, remote_ip, success ]`, `[ path, true_path, remote_ip, type ]`, `[ path, true_path, remote_ip, username ]`, `[ path, true_path, session_uuid, success ]`, `[ path, true_path, session_uuid, type ]`, `[ path, true_path, session_uuid, username ]`, `[ path, true_path, success, type ]`, `[ path, true_path, success, username ]`, `[ path, true_path, type, username ]`, `[ path, remote_ip, session_uuid, success ]`, `[ path, remote_ip, session_uuid, type ]`, `[ path, remote_ip, session_uuid, username ]`, `[ path, remote_ip, success, type ]`, `[ path, remote_ip, success, username ]`, `[ path, remote_ip, type, username ]`, `[ path, session_uuid, success, type ]`, `[ path, session_uuid, success, username ]`, `[ path, session_uuid, type, username ]`, `[ path, success, type, username ]`, `[ true_path, remote_ip, session_uuid, success ]`, `[ true_path, remote_ip, session_uuid, type ]`, `[ true_path, remote_ip, session_uuid, username ]`, `[ true_path, remote_ip, success, type ]`, `[ true_path, remote_ip, success, username ]`, `[ true_path, remote_ip, type, username ]`, `[ true_path, session_uuid, success, type ]`, `[ true_path, session_uuid, success, username ]`, `[ true_path, session_uuid, type, username ]`, `[ true_path, success, type, username ]`, `[ remote_ip, session_uuid, success, type ]`, `[ remote_ip, session_uuid, success, username ]`, `[ remote_ip, session_uuid, type, username ]`, `[ remote_ip, success, type, username ]`, `[ session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip ]`, `[ start_date, end_date, path, true_path, session_uuid ]`, `[ start_date, end_date, path, true_path, success ]`, `[ start_date, end_date, path, true_path, type ]`, `[ start_date, end_date, path, true_path, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid ]`, `[ start_date, end_date, path, remote_ip, success ]`, `[ start_date, end_date, path, remote_ip, type ]`, `[ start_date, end_date, path, remote_ip, username ]`, `[ start_date, end_date, path, session_uuid, success ]`, `[ start_date, end_date, path, session_uuid, type ]`, `[ start_date, end_date, path, session_uuid, username ]`, `[ start_date, end_date, path, success, type ]`, `[ start_date, end_date, path, success, username ]`, `[ start_date, end_date, path, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid ]`, `[ start_date, end_date, true_path, remote_ip, success ]`, `[ start_date, end_date, true_path, remote_ip, type ]`, `[ start_date, end_date, true_path, remote_ip, username ]`, `[ start_date, end_date, true_path, session_uuid, success ]`, `[ start_date, end_date, true_path, session_uuid, type ]`, `[ start_date, end_date, true_path, session_uuid, username ]`, `[ start_date, end_date, true_path, success, type ]`, `[ start_date, end_date, true_path, success, username ]`, `[ start_date, end_date, true_path, type, username ]`, `[ start_date, end_date, remote_ip, session_uuid, success ]`, `[ start_date, end_date, remote_ip, session_uuid, type ]`, `[ start_date, end_date, remote_ip, session_uuid, username ]`, `[ start_date, end_date, remote_ip, success, type ]`, `[ start_date, end_date, remote_ip, success, username ]`, `[ start_date, end_date, remote_ip, type, username ]`, `[ start_date, end_date, session_uuid, success, type ]`, `[ start_date, end_date, session_uuid, success, username ]`, `[ start_date, end_date, session_uuid, type, username ]`, `[ start_date, end_date, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid ]`, `[ start_date, path, true_path, remote_ip, success ]`, `[ start_date, path, true_path, remote_ip, type ]`, `[ start_date, path, true_path, remote_ip, username ]`, `[ start_date, path, true_path, session_uuid, success ]`, `[ start_date, path, true_path, session_uuid, type ]`, `[ start_date, path, true_path, session_uuid, username ]`, `[ start_date, path, true_path, success, type ]`, `[ start_date, path, true_path, success, username ]`, `[ start_date, path, true_path, type, username ]`, `[ start_date, path, remote_ip, session_uuid, success ]`, `[ start_date, path, remote_ip, session_uuid, type ]`, `[ start_date, path, remote_ip, session_uuid, username ]`, `[ start_date, path, remote_ip, success, type ]`, `[ start_date, path, remote_ip, success, username ]`, `[ start_date, path, remote_ip, type, username ]`, `[ start_date, path, session_uuid, success, type ]`, `[ start_date, path, session_uuid, success, username ]`, `[ start_date, path, session_uuid, type, username ]`, `[ start_date, path, success, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid, success ]`, `[ start_date, true_path, remote_ip, session_uuid, type ]`, `[ start_date, true_path, remote_ip, session_uuid, username ]`, `[ start_date, true_path, remote_ip, success, type ]`, `[ start_date, true_path, remote_ip, success, username ]`, `[ start_date, true_path, remote_ip, type, username ]`, `[ start_date, true_path, session_uuid, success, type ]`, `[ start_date, true_path, session_uuid, success, username ]`, `[ start_date, true_path, session_uuid, type, username ]`, `[ start_date, true_path, success, type, username ]`, `[ start_date, remote_ip, session_uuid, success, type ]`, `[ start_date, remote_ip, session_uuid, success, username ]`, `[ start_date, remote_ip, session_uuid, type, username ]`, `[ start_date, remote_ip, success, type, username ]`, `[ start_date, session_uuid, success, type, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid ]`, `[ end_date, path, true_path, remote_ip, success ]`, `[ end_date, path, true_path, remote_ip, type ]`, `[ end_date, path, true_path, remote_ip, username ]`, `[ end_date, path, true_path, session_uuid, success ]`, `[ end_date, path, true_path, session_uuid, type ]`, `[ end_date, path, true_path, session_uuid, username ]`, `[ end_date, path, true_path, success, type ]`, `[ end_date, path, true_path, success, username ]`, `[ end_date, path, true_path, type, username ]`, `[ end_date, path, remote_ip, session_uuid, success ]`, `[ end_date, path, remote_ip, session_uuid, type ]`, `[ end_date, path, remote_ip, session_uuid, username ]`, `[ end_date, path, remote_ip, success, type ]`, `[ end_date, path, remote_ip, success, username ]`, `[ end_date, path, remote_ip, type, username ]`, `[ end_date, path, session_uuid, success, type ]`, `[ end_date, path, session_uuid, success, username ]`, `[ end_date, path, session_uuid, type, username ]`, `[ end_date, path, success, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid, success ]`, `[ end_date, true_path, remote_ip, session_uuid, type ]`, `[ end_date, true_path, remote_ip, session_uuid, username ]`, `[ end_date, true_path, remote_ip, success, type ]`, `[ end_date, true_path, remote_ip, success, username ]`, `[ end_date, true_path, remote_ip, type, username ]`, `[ end_date, true_path, session_uuid, success, type ]`, `[ end_date, true_path, session_uuid, success, username ]`, `[ end_date, true_path, session_uuid, type, username ]`, `[ end_date, true_path, success, type, username ]`, `[ end_date, remote_ip, session_uuid, success, type ]`, `[ end_date, remote_ip, session_uuid, success, username ]`, `[ end_date, remote_ip, session_uuid, type, username ]`, `[ end_date, remote_ip, success, type, username ]`, `[ end_date, session_uuid, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid, success ]`, `[ path, true_path, remote_ip, session_uuid, type ]`, `[ path, true_path, remote_ip, session_uuid, username ]`, `[ path, true_path, remote_ip, success, type ]`, `[ path, true_path, remote_ip, success, username ]`, `[ path, true_path, remote_ip, type, username ]`, `[ path, true_path, session_uuid, success, type ]`, `[ path, true_path, session_uuid, success, username ]`, `[ path, true_path, session_uuid, type, username ]`, `[ path, true_path, success, type, username ]`, `[ path, remote_ip, session_uuid, success, type ]`, `[ path, remote_ip, session_uuid, success, username ]`, `[ path, remote_ip, session_uuid, type, username ]`, `[ path, remote_ip, success, type, username ]`, `[ path, session_uuid, success, type, username ]`, `[ true_path, remote_ip, session_uuid, success, type ]`, `[ true_path, remote_ip, session_uuid, success, username ]`, `[ true_path, remote_ip, session_uuid, type, username ]`, `[ true_path, remote_ip, success, type, username ]`, `[ true_path, session_uuid, success, type, username ]`, `[ remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid ]`, `[ start_date, end_date, path, true_path, remote_ip, success ]`, `[ start_date, end_date, path, true_path, remote_ip, type ]`, `[ start_date, end_date, path, true_path, remote_ip, username ]`, `[ start_date, end_date, path, true_path, session_uuid, success ]`, `[ start_date, end_date, path, true_path, session_uuid, type ]`, `[ start_date, end_date, path, true_path, session_uuid, username ]`, `[ start_date, end_date, path, true_path, success, type ]`, `[ start_date, end_date, path, true_path, success, username ]`, `[ start_date, end_date, path, true_path, type, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success ]`, `[ start_date, end_date, path, remote_ip, session_uuid, type ]`, `[ start_date, end_date, path, remote_ip, session_uuid, username ]`, `[ start_date, end_date, path, remote_ip, success, type ]`, `[ start_date, end_date, path, remote_ip, success, username ]`, `[ start_date, end_date, path, remote_ip, type, username ]`, `[ start_date, end_date, path, session_uuid, success, type ]`, `[ start_date, end_date, path, session_uuid, success, username ]`, `[ start_date, end_date, path, session_uuid, type, username ]`, `[ start_date, end_date, path, success, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, type ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, username ]`, `[ start_date, end_date, true_path, remote_ip, success, type ]`, `[ start_date, end_date, true_path, remote_ip, success, username ]`, `[ start_date, end_date, true_path, remote_ip, type, username ]`, `[ start_date, end_date, true_path, session_uuid, success, type ]`, `[ start_date, end_date, true_path, session_uuid, success, username ]`, `[ start_date, end_date, true_path, session_uuid, type, username ]`, `[ start_date, end_date, true_path, success, type, username ]`, `[ start_date, end_date, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, remote_ip, success, type, username ]`, `[ start_date, end_date, session_uuid, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success ]`, `[ start_date, path, true_path, remote_ip, session_uuid, type ]`, `[ start_date, path, true_path, remote_ip, session_uuid, username ]`, `[ start_date, path, true_path, remote_ip, success, type ]`, `[ start_date, path, true_path, remote_ip, success, username ]`, `[ start_date, path, true_path, remote_ip, type, username ]`, `[ start_date, path, true_path, session_uuid, success, type ]`, `[ start_date, path, true_path, session_uuid, success, username ]`, `[ start_date, path, true_path, session_uuid, type, username ]`, `[ start_date, path, true_path, success, type, username ]`, `[ start_date, path, remote_ip, session_uuid, success, type ]`, `[ start_date, path, remote_ip, session_uuid, success, username ]`, `[ start_date, path, remote_ip, session_uuid, type, username ]`, `[ start_date, path, remote_ip, success, type, username ]`, `[ start_date, path, session_uuid, success, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, true_path, remote_ip, success, type, username ]`, `[ start_date, true_path, session_uuid, success, type, username ]`, `[ start_date, remote_ip, session_uuid, success, type, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid, success ]`, `[ end_date, path, true_path, remote_ip, session_uuid, type ]`, `[ end_date, path, true_path, remote_ip, session_uuid, username ]`, `[ end_date, path, true_path, remote_ip, success, type ]`, `[ end_date, path, true_path, remote_ip, success, username ]`, `[ end_date, path, true_path, remote_ip, type, username ]`, `[ end_date, path, true_path, session_uuid, success, type ]`, `[ end_date, path, true_path, session_uuid, success, username ]`, `[ end_date, path, true_path, session_uuid, type, username ]`, `[ end_date, path, true_path, success, type, username ]`, `[ end_date, path, remote_ip, session_uuid, success, type ]`, `[ end_date, path, remote_ip, session_uuid, success, username ]`, `[ end_date, path, remote_ip, session_uuid, type, username ]`, `[ end_date, path, remote_ip, success, type, username ]`, `[ end_date, path, session_uuid, success, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid, success, type ]`, `[ end_date, true_path, remote_ip, session_uuid, success, username ]`, `[ end_date, true_path, remote_ip, session_uuid, type, username ]`, `[ end_date, true_path, remote_ip, success, type, username ]`, `[ end_date, true_path, session_uuid, success, type, username ]`, `[ end_date, remote_ip, session_uuid, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid, success, type ]`, `[ path, true_path, remote_ip, session_uuid, success, username ]`, `[ path, true_path, remote_ip, session_uuid, type, username ]`, `[ path, true_path, remote_ip, success, type, username ]`, `[ path, true_path, session_uuid, success, type, username ]`, `[ path, remote_ip, session_uuid, success, type, username ]`, `[ true_path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, success ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, type ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, username ]`, `[ start_date, end_date, path, true_path, remote_ip, success, type ]`, `[ start_date, end_date, path, true_path, remote_ip, success, username ]`, `[ start_date, end_date, path, true_path, remote_ip, type, username ]`, `[ start_date, end_date, path, true_path, session_uuid, success, type ]`, `[ start_date, end_date, path, true_path, session_uuid, success, username ]`, `[ start_date, end_date, path, true_path, session_uuid, type, username ]`, `[ start_date, end_date, path, true_path, success, type, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, path, remote_ip, success, type, username ]`, `[ start_date, end_date, path, session_uuid, success, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, true_path, remote_ip, success, type, username ]`, `[ start_date, end_date, true_path, session_uuid, success, type, username ]`, `[ start_date, end_date, remote_ip, session_uuid, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, path, true_path, remote_ip, success, type, username ]`, `[ start_date, path, true_path, session_uuid, success, type, username ]`, `[ start_date, path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, true_path, remote_ip, session_uuid, success, type, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid, success, type ]`, `[ end_date, path, true_path, remote_ip, session_uuid, success, username ]`, `[ end_date, path, true_path, remote_ip, session_uuid, type, username ]`, `[ end_date, path, true_path, remote_ip, success, type, username ]`, `[ end_date, path, true_path, session_uuid, success, type, username ]`, `[ end_date, path, remote_ip, session_uuid, success, type, username ]`, `[ end_date, true_path, remote_ip, session_uuid, success, type, username ]`, `[ path, true_path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, success, type ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, success, username ]`, `[ start_date, end_date, path, true_path, remote_ip, session_uuid, type, username ]`, `[ start_date, end_date, path, true_path, remote_ip, success, type, username ]`, `[ start_date, end_date, path, true_path, session_uuid, success, type, username ]`, `[ start_date, end_date, path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, end_date, true_path, remote_ip, session_uuid, success, type, username ]`, `[ start_date, path, true_path, remote_ip, session_uuid, success, type, username ]` or `[ end_date, path, true_path, remote_ip, session_uuid, success, type, username ]`.
def list(params=None, options=None):
    if not isinstance(params, dict):
        params = {}
    if not isinstance(options, dict):
        options = {}
    if "cursor" in params and not isinstance(params["cursor"], str):
        raise InvalidParameterError("Bad parameter: cursor must be an str")
    if "per_page" in params and not isinstance(params["per_page"], int):
        raise InvalidParameterError("Bad parameter: per_page must be an int")
    if "filter" in params and not isinstance(params["filter"], dict):
        raise InvalidParameterError("Bad parameter: filter must be an dict")
    if "filter_prefix" in params and not isinstance(
        params["filter_prefix"], dict
    ):
        raise InvalidParameterError(
            "Bad parameter: filter_prefix must be an dict"
        )
    return ListObj(FtpActionLog, "GET", "/ftp_action_logs", params, options)


def all(params=None, options=None):
    list(params, options)


def new(*args, **kwargs):
    return FtpActionLog(*args, **kwargs)
